OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} rendelkezésre áll. További információ a frissítéshez.",
    "Channel updated" : "Csatorna frissítve",
    "Update notifications" : "Frissítési értesítés",
    "The update server could not be reached since %d days to check for new updates." : "A frissítési szerver  %d napja nem elérhető a frissítések kereséséhez.",
    "Please check the Nextcloud and server log files for errors." : "Kérlek nézd meg a Nextcloud és a szervernaplókat a hibák miatt.",
    "Update to %1$s is available." : "%1$s frissítés elérhető.",
    "Update for %1$s to version %2$s is available." : "%1$s frissíthető %2$s verzióra.",
    "Update for {app} to version %s is available." : "{app} %s verzió frissítése elérhető",
    "Update notification" : "Frissítési értesítés",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Megjeleníti a Nextcloud frissítéseiről szóló értesítéseket és SSO hozzáférést nyújt a frissítésekhez.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Az általad futtatott verziót már nem karban tartott. Kérlek frissítsd egy támogatott verzióra amint lehetséges.",
    "Apps missing updates" : "Alkalmazások frissítés nélkül",
    "View in store" : "Nézze meg a boltban",
    "Apps with available updates" : "Alkalmazások frissítéssel",
    "Open updater" : "Frissítő megnyitása",
    "Download now" : "Letöltés most",
    "What's new?" : "Újdonságok?",
    "The update check is not yet finished. Please refresh the page." : "A frissítéskeresés még nem ért véget. Kérjük frissítsd az oldalt.",
    "Your version is up to date." : "Verzió frissítve.",
    "A non-default update server is in use to be checked for updates:" : "Egy nem alapértelmezett szervert használunk a frissítések kereséséhez:",
    "Update channel:" : "Frissítési csatorna:",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Vedd figyelembe, hogy egy firssítés megjelenése után eltarthat egy darabig míg itt megjelenik. Fokozatosan juttatjuk el a frissítéseket a felhaszálóinkhoz és néha kihagyunk egy-egy verziót, ha problémák merülnek fel.",
    "Notify members of the following groups about available updates:" : "A következő csoport tagjainak értesítése az elérhető frissítésekről:",
    "Only notification for app updates are available." : "Csak az értesítő alkalmazás frissítései érhetők el.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A kiválasztott frissítési csatorna dedikált értesítéseket jelenít meg a szerver elavulásakor.",
    "The selected update channel does not support updates of the server." : "A kiválasztott frissítése csatorna nem támogatja a szerver frissítéseit.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Új verzió érhető el: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Ellenőrizve ekkor: {lastCheckedDate}",
    "Checking apps for compatible updates" : "Alkalmazások ellenőrzése kompatibilis frissítéséhez",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Ellenőrizd, hogy a config.php-dben nincs-e beállítva a <samp>appstoreenabled</samp> false-ra.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Nem lehet csatlakozni az alkalmazásbolthoz, vagy az nem adott vissza frissítéseket egyáltalán. Keress frissítéseket kézzel, vagy győződj meg arról, hogy a szervered hozzáfér az internethez és eléri az alkalmazásboltot.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Minden</strong> alkalmazás felfrissítve a legújabb verzióra.",
    "View changelog" : "Változásnapló megjelenítése",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  alkalmazásnak nincs elérhető frissítése ehhez a verzióhoz","<strong>%n</strong> alkalmazásnak nincs elérhető frissítése ehhez a verzióhoz"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Mindig frissíthetsz az újabb verzióra vagy kísérleti csatornára, de visszafelé sosem frissíthetsz egy jóval stabilabb verzióra.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>Béta</strong>, egy előzetes verzió kizárólag az új funkciók tesztelésére, nem élő környezetbe."
},
"nplurals=2; plural=(n != 1);");
